==> nextcloud-31.0.6.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/ar.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "مُعرِّف السحابة الاتحادية غير صحيح",
    "Server to server sharing is not enabled on this server" : "المُشاركة من خادوم إلى خادوم غير مُمكّنة على هذا الخادوم",
    "Couldn't establish a federated share." : "تعذّر تأسيس مُشاركة السحابة الاتحادية.",
    "Couldn't establish a federated share, maybe the password was wrong." : "تعذّر تأسيس مُشاركة السحابة الاتحادية. ربما بسبب كلمة مرور غير صحيحة",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "تمّ إرسال طلب مُشاركة السحابة الاتحادية، وسوف تصلك الدعوة. رجاءً، تحقّق من إشعاراتك.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "تعذّر تأسيس مُشاركة السحابة الاتحادية. يبدو أن إصدار خادم نكست كلاود الذي طلبت الاتحاد معه قديمٌ ( ما قبل الإصدار 9). ",
    "It is not allowed to send federated group shares from this server." : "غيرُ مسموحٍ بإرسال مشاركات مجموعات السحابة الاتحادية من هذا الخادوم.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "فشلت مشاركة %1$s بسبب أن هذه العنصر سبقت مشاركته مع الحساب  %2$s",
    "Not allowed to create a federated share to the same account" : "غير مسموح بإنشاء مشاركة السحابة الاتحادية مع نفس الحساب",
    "Federated shares require read permissions" : "مشاركات السحابة الاتحادية تتطلب إذونات قراءة",
    "File is already shared with %s" : "سبقت مُشاركة الملف مع %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "المُشاركة %1$s فشلت؛ تعذّر إيجاد %2$s. يُمكن أن يكون هذ بسبب أن الخادوم لا يُمكن الوصول إليه حاليّاً أو أنه يستعمل شهادةً ذاتيّة التصديق self-signed certificate.",
    "Could not find share" : "تعذّر العثور على المُشاركة",
    "Federated sharing" : "مُشاركة السحابة الاتحادية",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "أنت تلقيت {share} كُمشاركة بعيدة من {user} (نيابةً عن {behalf})",
    "You received {share} as a remote share from {user}" : "أنت تلقّيتَ {share} كُمشاركة بعيدة من {user}  ",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Federated Cloud Sharing" : "المشاركة عبر السحابة الاتحادية",
    "Sharing" : "المشاركة",
    "Federated file sharing" : "مُشاركة ملف عبر السحابة الاتحادية",
    "Provide federated file sharing across servers" : "توفير مشاركة الملفات عبر خوادم السحابة الاتحادية",
    "Confirm data upload to lookup server" : "تأكيد تحميل البيانات لخادوم البحث",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "عند تفعيل هذا الخيار، ستتم تلقائياً مزامنة جميع خصائص الحساب (على سبيل المثال عنوان البريد الإلكتروني) التي تم تعيين \"نطاق الرؤية\" visibility scope فيها على \"منشور published\"، وإرسالها إلى نظام خارجي وإتاحتها في دفتر عناوين عمومي شامل.",
    "Disable upload" : "تعطيل الرفع",
    "Enable data upload" : "تمكين رفع البيانات",
    "Confirm querying lookup server" : "تأكيد استعلام خادوم البحث",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "عند تمكين هذا الخيار، سيتم إرسال إدخال البحث عند إنشاء المشاركات إلى نظام خارجي يوفر دفتر عناوين شامل وعمومي.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "يستعمل هذا لاسترجاع معرف السحابة الاتحادية وذلك لتسهيل المشاركات الاتحادية",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "علاوة على ذلك، قد يتم إرسال عناوين البريد الإلكتروني للمستخدِمين إلى ذلك النظام للتحقق منها.",
    "Disable querying" : "تعطيل الاستعلام",
    "Enable querying" : "تمكين الاستعلام",
    "Unable to update federated files sharing config" : "تعذر تحديث تهيئة مشاركة الملفات عبر السحابة الاتحادية",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "اضبط كيفية مشاركة الأشخاص بين الخوادم. هذا يشمل المشاركات بين الأشخاص على هذا الخادوم أيضاً إذا كانوا يستعملون المشاركة عبر السحابة الاتحادية.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "السماح للأشخاص على هذا الخادوم بإرسال مشاركات إلى خوادم أخرى (هذا الخيار يسمح أيضاً بالوصول عبر WebDAV إلى المشاركات العمومية)",
    "Allow people on this server to receive shares from other servers" : "السماح للأشخاص على هذا الخادوم باستقبال مشاركات من خوادم أخرى",
    "Allow people on this server to send shares to groups on other servers" : "السماح للأشخاص على هذا الخادوم بإرسال مشاركات إلى مجموعات على خوادم أخرى",
    "Allow people on this server to receive group shares from other servers" : "السماح للأشخاص على هذا الخادوم بإستقبال مشاركات لمجموعات من خوادم أخرى",
    "The lookup server is only available for global scale." : "خادوم البحث متاحٌ فقط على المستوى الشامل.",
    "Search global and public address book for people" : "البحث في دفتر العناوين الشامل و دفاتر العناوين العامة للأشخاص",
    "Allow people to publish their data to a global and public address book" : "السماح للأشخاص بنشر بياناتهم إلى دفتر العناوين الشامل و دفتر العناوين العامة للأشخاص",
    "Trusted federation" : "إتحاد موثوق",
    "Automatically accept shares from trusted federated accounts and groups by default" : "يتم آليّاً قبول المشاركات من حسابات ومجموعات الاتحادات الموثوقة بشكل تلقائي ",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الاتحادية، أنظُر {url} ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الاتحادية",
    "Cloud ID copied to the clipboard" : "تمّ نسخ مُعرِّف السحابة إلى الحافظة",
    "Copy to clipboard" : "نسخ الرابط",
    "Clipboard not available. Please copy the cloud ID manually." : "الحافظة غير متوفرة. رجاءً، قم بنسخ مُعرِّف السحابة يدوياً.",
    "Copied!" : "تمَّ النسخ!",
    "Federated Cloud" : "السحابة الاتحادية",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "يُمكنك المشاركة مع أي شخص يستخدم خادم نكست كلاود أو خوادم وخدمات أخرى متوافقة مع بروتوكول Open Cloud Mesh (OCM)! فقط ضع مُعرّف السحابة الاتحادية في مربع حوار المُشاركة؛ و الذي سيكون شكله على هذا النسق: person@cloud.example.com",
    "Your Federated Cloud ID" : "مُعرِّف شبكتك الاتحادية",
    "Share it so your friends can share files with you:" : "شاركه مع أصدقائك بحيث يمكنهم مُشاركة الملفات معك:",
    "Facebook" : "فيسبوك",
    "X (formerly Twitter)" : "منصة X (تويتر سابقاً)",
    "formerly Twitter" : "تويتر سابقاً",
    "Mastodon" : "برنامج ماستودون Mastodon",
    "Add to your website" : "أضِف إلى موقعك على الويب",
    "Share with me via Nextcloud" : "شاركه معي عبر النكست كلاود",
    "HTML Code:" : "كود HTML: ",
    "Cancel" : "إلغاء",
    "Add remote share" : "إضافة مشاركة بعيدة remote",
    "Remote share" : "مُشاركة بعيدة remote",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "هل ترغب في إضافة مُشاركة بعيدة remote ـ {name} من {owner}@{remote}؟",
    "Remote share password" : "كلمة مرور المشاركة البعيدة remote",
    "Incoming share could not be processed" : "لا يمكن معالجة المشاركة الواردة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-31.0.10.tar.bz2: nextcloud/apps/federatedfilesharing/l10n/ar.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "مُعرِّف السحابة الاتحادية غير صحيح",
    "Server to server sharing is not enabled on this server" : "المُشاركة من خادوم إلى خادوم غير مُمكّنة على هذا الخادوم",
    "Couldn't establish a federated share." : "تعذّر تأسيس مُشاركة السحابة الاتحادية.",
    "Couldn't establish a federated share, maybe the password was wrong." : "تعذّر تأسيس مُشاركة السحابة الاتحادية. ربما بسبب كلمة مرور غير صحيحة",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "تمّ إرسال طلب مُشاركة السحابة الاتحادية، وسوف تصلك الدعوة. رجاءً، تحقّق من إشعاراتك.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "تعذّر تأسيس مُشاركة السحابة الاتحادية. يبدو أن إصدار خادم نكست كلاود الذي طلبت الاتحاد معه قديمٌ ( ما قبل الإصدار 9). ",
    "It is not allowed to send federated group shares from this server." : "غيرُ مسموحٍ بإرسال مشاركات مجموعات السحابة الاتحادية من هذا الخادوم.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "فشلت مشاركة %1$s بسبب أن هذه العنصر سبقت مشاركته مع الحساب  %2$s",
    "Not allowed to create a federated share to the same account" : "غير مسموح بإنشاء مشاركة السحابة الاتحادية مع نفس الحساب",
    "Federated shares require read permissions" : "مشاركات السحابة الاتحادية تتطلب إذونات قراءة",
    "File is already shared with %s" : "سبقت مُشاركة الملف مع %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "المُشاركة %1$s فشلت؛ تعذّر إيجاد %2$s. يُمكن أن يكون هذ بسبب أن الخادوم لا يُمكن الوصول إليه حاليّاً أو أنه يستعمل شهادةً ذاتيّة التصديق self-signed certificate.",
    "Could not find share" : "تعذّر العثور على المُشاركة",
    "Federated sharing" : "مُشاركة السحابة الاتحادية",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "أنت تلقيت {share} كُمشاركة بعيدة من {user} (نيابةً عن {behalf})",
    "You received {share} as a remote share from {user}" : "أنت تلقّيتَ {share} كُمشاركة بعيدة من {user}  ",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "Federated Cloud Sharing" : "المشاركة عبر السحابة الاتحادية",
    "Sharing" : "المشاركة",
    "Federated file sharing" : "مُشاركة ملف عبر السحابة الاتحادية",
    "Provide federated file sharing across servers" : "توفير مشاركة الملفات عبر خوادم السحابة الاتحادية",
    "Confirm data upload to lookup server" : "تأكيد تحميل البيانات لخادوم البحث",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "عند تفعيل هذا الخيار، ستتم تلقائياً مزامنة جميع خصائص الحساب (على سبيل المثال عنوان البريد الإلكتروني) التي تم تعيين \"نطاق الرؤية\" visibility scope فيها على \"منشور published\"، وإرسالها إلى نظام خارجي وإتاحتها في دفتر عناوين عمومي شامل.",
    "Disable upload" : "تعطيل الرفع",
    "Enable data upload" : "تمكين رفع البيانات",
    "Confirm querying lookup server" : "تأكيد استعلام خادوم البحث",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "عند تمكين هذا الخيار، سيتم إرسال إدخال البحث عند إنشاء المشاركات إلى نظام خارجي يوفر دفتر عناوين شامل وعمومي.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "يستعمل هذا لاسترجاع معرف السحابة الاتحادية وذلك لتسهيل المشاركات الاتحادية",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "علاوة على ذلك، قد يتم إرسال عناوين البريد الإلكتروني للمستخدِمين إلى ذلك النظام للتحقق منها.",
    "Disable querying" : "تعطيل الاستعلام",
    "Enable querying" : "تمكين الاستعلام",
    "Unable to update federated files sharing config" : "تعذر تحديث تهيئة مشاركة الملفات عبر السحابة الاتحادية",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "اضبط كيفية مشاركة الأشخاص بين الخوادم. هذا يشمل المشاركات بين الأشخاص على هذا الخادوم أيضاً إذا كانوا يستعملون المشاركة عبر السحابة الاتحادية.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "السماح للأشخاص على هذا الخادوم بإرسال مشاركات إلى خوادم أخرى (هذا الخيار يسمح أيضاً بالوصول عبر WebDAV إلى المشاركات العمومية)",
    "Allow people on this server to receive shares from other servers" : "السماح للأشخاص على هذا الخادوم باستقبال مشاركات من خوادم أخرى",
    "Allow people on this server to send shares to groups on other servers" : "السماح للأشخاص على هذا الخادوم بإرسال مشاركات إلى مجموعات على خوادم أخرى",
    "Allow people on this server to receive group shares from other servers" : "السماح للأشخاص على هذا الخادوم بإستقبال مشاركات لمجموعات من خوادم أخرى",
    "The lookup server is only available for global scale." : "خادوم البحث متاحٌ فقط على المستوى الشامل.",
    "Search global and public address book for people" : "البحث في دفتر العناوين الشامل و دفاتر العناوين العامة للأشخاص",
    "Allow people to publish their data to a global and public address book" : "السماح للأشخاص بنشر بياناتهم إلى دفتر العناوين الشامل و دفتر العناوين العامة للأشخاص",
    "Trusted federation" : "إتحاد موثوق",
    "Automatically accept shares from trusted federated accounts and groups by default" : "يتم آليّاً قبول المشاركات من حسابات ومجموعات الاتحادات الموثوقة بشكل تلقائي ",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الاتحادية، أنظُر {url} ",
    "Share with me through my #Nextcloud Federated Cloud ID" : "شارك معي عبر #مُعرّف سحابة نكست كلاود الاتحادية",
    "Share with me via Nextcloud" : "شاركه معي عبر النكست كلاود",
    "Copy" : "إنسَخ",
    "Clipboard not available. Please copy the cloud ID manually." : "الحافظة غير متوفرة. رجاءً، قم بنسخ مُعرِّف السحابة يدوياً.",
    "Copied!" : "تمَّ النسخ!",
    "Federated Cloud" : "السحابة الاتحادية",
    "Your Federated Cloud ID" : "مُعرِّف شبكتك الاتحادية",
    "Share it so your friends can share files with you:" : "شاركه مع أصدقائك بحيث يمكنهم مُشاركة الملفات معك:",
    "Facebook" : "فيسبوك",
    "X (formerly Twitter)" : "منصة X (تويتر سابقاً)",
    "formerly Twitter" : "تويتر سابقاً",
    "Mastodon" : "برنامج ماستودون Mastodon",
    "Add to your website" : "أضِف إلى موقعك على الويب",
    "HTML Code:" : "كود HTML: ",
    "Cancel" : "إلغاء",
    "Add remote share" : "إضافة مشاركة بعيدة remote",
    "Remote share" : "مُشاركة بعيدة remote",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "هل ترغب في إضافة مُشاركة بعيدة remote ـ {name} من {owner}@{remote}؟",
    "Remote share password" : "كلمة مرور المشاركة البعيدة remote",
    "Incoming share could not be processed" : "لا يمكن معالجة المشاركة الواردة",
    "Cloud ID copied to the clipboard" : "تمّ نسخ مُعرِّف السحابة إلى الحافظة",
    "Copy to clipboard" : "نسخ الرابط",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "يُمكنك المشاركة مع أي شخص يستخدم خادم نكست كلاود أو خوادم وخدمات أخرى متوافقة مع بروتوكول Open Cloud Mesh (OCM)! فقط ضع مُعرّف السحابة الاتحادية في مربع حوار المُشاركة؛ و الذي سيكون شكله على هذا النسق: person@cloud.example.com"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
